Other Libraries
===============

.. _boto:

Boto
----

.. _aiobotocore:

aiobotocore
^^^^^^^^^^^

.. automodule:: ddtrace.contrib.aiobotocore


.. _boto2:

Boto2
^^^^^

.. automodule:: ddtrace.contrib.boto


.. _botocore:

Botocore
^^^^^^^^

.. automodule:: ddtrace.contrib.botocore



.. _futures:

Futures
-------

.. automodule:: ddtrace.contrib.futures


.. _celery:

Celery
------

.. automodule:: ddtrace.contrib.celery


.. _kombu:

Kombu
------

.. automodule:: ddtrace.contrib.kombu


.. _httplib:

httplib
-------

.. automodule:: ddtrace.contrib.httplib

.. _requests:

Requests
--------

.. automodule:: ddtrace.contrib.requests

.. _grpc:

Grpc
----

.. automodule:: ddtrace.contrib.grpc

.. _jinja2:

Jinja2
------

.. automodule:: ddtrace.contrib.jinja2

.. _mako:

Mako
------

.. automodule:: ddtrace.contrib.mako
